@@ -1,12 +1,14 @@
-import subprocess
 from tempfile import TemporaryDirectory
 
 import pytest
 from packaging.version import Version
 
+import pip_audit._virtual_env as _virtual_env
+from pip_audit import _subprocess
 from pip_audit._virtual_env import VirtualEnv, VirtualEnvError
 
 
+@pytest.mark.online
 def test_virtual_env():
     with TemporaryDirectory() as ve_dir:
         ve = VirtualEnv(["flask==2.0.1"])
@@ -23,15 +25,15 @@ def test_virtual_env_incorrect_usage():
 
 
 def test_virtual_env_failed_package_installation(monkeypatch):
-    original_run = subprocess.run
+    original_run = _subprocess.run
 
     def run_mock(args, **kwargs):
         if "flask==2.0.1" in args:
-            raise subprocess.CalledProcessError(-1, str())
+            raise _subprocess.CalledProcessError("barf")
         # If it's not the package installation command, then call the original run
         return original_run(args, **kwargs)
 
-    monkeypatch.setattr(subprocess, "run", run_mock)
+    monkeypatch.setattr(_virtual_env, "run", run_mock)
 
     with TemporaryDirectory() as ve_dir:
         ve = VirtualEnv(["flask==2.0.1"])
@@ -40,17 +42,17 @@ def test_virtual_env_failed_package_installation(monkeypatch):
 
 
 def test_virtual_env_failed_pip_upgrade(monkeypatch):
-    original_run = subprocess.run
+    original_run = _subprocess.run
 
     def run_mock(args, **kwargs):
         # We have to be a bit more specific than usual here because the `EnvBuilder` invokes
         # `ensurepip` with similar looking arguments and we DON'T want to mock that call.
         if set(["install", "--upgrade", "pip"]).issubset(set(args)):
-            raise subprocess.CalledProcessError(-1, str())
+            raise _subprocess.CalledProcessError("barf")
         # If it's not a call to upgrade pip, then call the original run
         return original_run(args, **kwargs)
 
-    monkeypatch.setattr(subprocess, "run", run_mock)
+    monkeypatch.setattr(_virtual_env, "run", run_mock)
 
     with TemporaryDirectory() as ve_dir:
         ve = VirtualEnv(["flask==2.0.1"])
@@ -59,15 +61,15 @@ def test_virtual_env_failed_pip_upgrade(monkeypatch):
 
 
 def test_virtual_env_failed_pip_list(monkeypatch):
-    original_run = subprocess.run
+    original_run = _subprocess.run
 
     def run_mock(args, **kwargs):
-        if "json" in args:
-            raise subprocess.CalledProcessError(-1, str())
+        if {"list", "--format", "json"}.issubset(set(args)):
+            raise _subprocess.CalledProcessError("barf")
         # If it's not a call to `pip list`, then call the original run
         return original_run(args, **kwargs)
 
-    monkeypatch.setattr(subprocess, "run", run_mock)
+    monkeypatch.setattr(_virtual_env, "run", run_mock)
 
     with TemporaryDirectory() as ve_dir:
         ve = VirtualEnv(["flask==2.0.1"])
